==> workflow-designer-plugin-6.2.0.5.jar: js/test-fixtures/SimpleLayout.js <==
var simpleLayoutJSON, simpleLayoutModelAttributes;

simpleLayoutJSON = {
    statuses: [{
        description: "",
        id: "E90E7D73-93DB-9308-034D-1C32D0638647",
        initial: false,
        name: "Closed",
        statusCategory: {
            colourName: "green",
            id: 1
        },
        statusId: "6",
        stepId: 4,
        x: 1318.0,
        y: 215.0
    }, {
        description: "",
        id: "BC195C3E-8BA3-6939-69B8-1C32527BD84D",
        initial: true,
        name: "Create",
        statusCategory: null,
        statusId: null,
        stepId: 1,
        x: 1491.0,
        y: 22.0
    }, {
        description: "",
        id: "30C0CF0A-FFAF-2F19-F968-1C32841F7BA8",
        initial: false,
        name: "In Progress",
        statusCategory: null,
        statusId: "3",
        stepId: 2,
        x: 1607.0,
        y: 99.0
    }, {
        description: "",
        id: "A8055B98-2CF0-45FF-C616-1C3252A7DFC1",
        initial: false,
        name: "Open",
        statusCategory: null,
        statusId: "1",
        stepId: 1,
        x: 1290.0,
        y: 98.0
    }, {
        description: "",
        id: "FCA5100A-F167-5B97-33A5-1C32B0CFE9B1",
        initial: false,
        name: "Reopened",
        statusCategory: null,
        statusId: "4",
        stepId: 3,
        x: 1444.0,
        y: 355.0
    },  {
        description: "",
        id: "14CDB221-6ED0-7725-9893-1C32E0F0156C",
        initial: false,
        name: "Resolved",
        statusCategory: null,
        statusId: "5",
        stepId: 5,
        x: 1570.0,
        y: 218.0
    }],
    transitions: [{
        actionId: 21,
        description: null,
        globalTransition: false,
        name: "Close",
        sourceAngle: 45,
        sourceId: "14CDB221-6ED0-7725-9893-1C32E0F0156C",
        targetAngle: 135,
        targetId: "E90E7D73-93DB-9308-034D-1C32D0638647",
        screenName: null,
        screenId: null,
        propertiesCount: 1,
        conditionsCount: 2,
        validatorsCount: 3,
        postFunctionsCount: 4
    }, {
        actionId: 1,
        description: null,
        globalTransition: false,
        name: "Create",
        sourceAngle: 0,
        sourceId: "BC195C3E-8BA3-6939-69B8-1C32527BD84D",
        targetAngle: 90,
        targetId: "A8055B98-2CF0-45FF-C616-1C3252A7DFC1",
        screenName: null,
        screenId: null,
        propertiesCount: 1,
        conditionsCount: 2,
        validatorsCount: 3,
        postFunctionsCount: 4
    }, {
        actionId: 11,
        description: null,
        globalTransition: false,
        name: "Resolve",
        sourceAngle: 180,
        sourceId: "30C0CF0A-FFAF-2F19-F968-1C32841F7BA8",
        targetAngle: 315,
        targetId: "14CDB221-6ED0-7725-9893-1C32E0F0156C",
        screenName: null,
        screenId: null,
        propertiesCount: 1,
        conditionsCount: 2,
        validatorsCount: 3,
        postFunctionsCount: 4
    }, {
        actionId: 31,
        description: null,
        globalTransition: false,
        name: "Start Progress",
        sourceAngle: 30,
        sourceId: "A8055B98-2CF0-45FF-C616-1C3252A7DFC1",
        targetAngle: 60,
        targetId: "30C0CF0A-FFAF-2F19-F968-1C32841F7BA8",
        screenName: null,
        screenId: null,
        propertiesCount: 1,
        conditionsCount: 2,
        validatorsCount: 3,
        postFunctionsCount: 4
    }],
    updateAuthor: {
        userName: "bob",
        displayName: "Bob Dude"
    },
    updatedDate: 100000
};

simpleLayoutModelAttributes = {
    statuses: [{
        description: "",
        id: "E90E7D73-93DB-9308-034D-1C32D0638647",
        initial: false,
        name: "Closed",
        statusCategory: {
            colourName: "green",
            id: 1
        },
        statusId: "6",
        stepId: 4,
        x: 1318,
        y: 215
    }, {
        description: "",
        id: "BC195C3E-8BA3-6939-69B8-1C32527BD84D",
        initial: true,
        name: "Create",
        statusCategory: null,
        statusId: null,
        stepId: 1,
        x: 1491,
        y: 22
    }, {
        description: "",
        id: "30C0CF0A-FFAF-2F19-F968-1C32841F7BA8",
        initial: false,
        name: "In Progress",
        statusCategory: null,
        statusId: "3",
        stepId: 2,
        x: 1607,
        y: 99
    }, {
        description: "",
        id: "A8055B98-2CF0-45FF-C616-1C3252A7DFC1",
        initial: false,
        name: "Open",
        statusCategory: null,
        statusId: "1",
        stepId: 1,
        x: 1290,
        y: 98
    }, {
        description: "",
        id: "FCA5100A-F167-5B97-33A5-1C32B0CFE9B1",
        initial: false,
        name: "Reopened",
        statusCategory: null,
        statusId: "4",
        stepId: 3,
        x: 1444,
        y: 355
    }, {
        description: "",
        id: "14CDB221-6ED0-7725-9893-1C32E0F0156C",
        initial: false,
        name: "Resolved",
        statusCategory: null,
        statusId: "5",
        stepId: 5,
        x: 1570,
        y: 218
    }],
    transitions: [{
        id: "A<21:14CDB221-6ED0-7725-9893-1C32E0F0156C:E90E7D73-93DB-9308-034D-1C32D0638647>",
        actionId: 21,
        description: null,
        globalTransition: false,
        name: "Close",
        sourceAngle: 45,
        sourceId: "14CDB221-6ED0-7725-9893-1C32E0F0156C",
        targetAngle: 135,
        targetId: "E90E7D73-93DB-9308-034D-1C32D0638647",
        screenName: null,
        screenId: null,
        propertiesCount: 1,
        conditionsCount: 2,
        validatorsCount: 3,
        postFunctionsCount: 4
    }, {
        id: "IA<1:BC195C3E-8BA3-6939-69B8-1C32527BD84D:A8055B98-2CF0-45FF-C616-1C3252A7DFC1>",
        actionId: 1,
        description: null,
        globalTransition: false,
        name: "Create",
        sourceAngle: 0,
        sourceId: "BC195C3E-8BA3-6939-69B8-1C32527BD84D",
        targetAngle: 90,
        targetId: "A8055B98-2CF0-45FF-C616-1C3252A7DFC1",
        screenName: null,
        screenId: null,
        propertiesCount: 1,
        conditionsCount: 2,
        validatorsCount: 3,
        postFunctionsCount: 4
    }, {
        id: "A<11:30C0CF0A-FFAF-2F19-F968-1C32841F7BA8:14CDB221-6ED0-7725-9893-1C32E0F0156C>",
        actionId: 11,
        description: null,
        globalTransition: false,
        name: "Resolve",
        sourceAngle: 180,
        sourceId: "30C0CF0A-FFAF-2F19-F968-1C32841F7BA8",
        targetAngle: 315,
        targetId: "14CDB221-6ED0-7725-9893-1C32E0F0156C",
        screenName: null,
        screenId: null,
        propertiesCount: 1,
        conditionsCount: 2,
        validatorsCount: 3,
        postFunctionsCount: 4
    }, {
        id: "A<31:A8055B98-2CF0-45FF-C616-1C3252A7DFC1:30C0CF0A-FFAF-2F19-F968-1C32841F7BA8>",
        actionId: 31,
        description: null,
        globalTransition: false,
        name: "Start Progress",
        sourceAngle: 30,
        sourceId: "A8055B98-2CF0-45FF-C616-1C3252A7DFC1",
        targetAngle: 60,
        targetId: "30C0CF0A-FFAF-2F19-F968-1C32841F7BA8",
        screenName: null,
        screenId: null,
        propertiesCount: 1,
        conditionsCount: 2,
        validatorsCount: 3,
        postFunctionsCount: 4
    }],
    updateAuthor: {
        userName: "bob",
        displayName: "Bob Dude"
    },
    updatedDate: 100000
};

==> workflow-designer-plugin-7.3.6.jar: js/test-fixtures/SimpleLayout.js <==
var simpleLayoutJSON, simpleLayoutModelAttributes;

simpleLayoutJSON = {
    statuses: [{
        description: "",
        id: "E90E7D73-93DB-9308-034D-1C32D0638647",
        initial: false,
        name: "Closed",
        statusCategory: {
            colourName: "green",
            id: 1
        },
        statusId: "6",
        stepId: 4,
        x: 1318.0,
        y: 215.0
    }, {
        description: "",
        id: "BC195C3E-8BA3-6939-69B8-1C32527BD84D",
        initial: true,
        name: "Create",
        statusCategory: null,
        statusId: null,
        stepId: 1,
        x: 1491.0,
        y: 22.0
    }, {
        description: "",
        id: "30C0CF0A-FFAF-2F19-F968-1C32841F7BA8",
        initial: false,
        name: "In Progress",
        statusCategory: null,
        statusId: "3",
        stepId: 2,
        x: 1607.0,
        y: 99.0
    }, {
        description: "",
        id: "A8055B98-2CF0-45FF-C616-1C3252A7DFC1",
        initial: false,
        name: "Open",
        statusCategory: null,
        statusId: "1",
        stepId: 1,
        x: 1290.0,
        y: 98.0
    }, {
        description: "",
        id: "FCA5100A-F167-5B97-33A5-1C32B0CFE9B1",
        initial: false,
        name: "Reopened",
        statusCategory: null,
        statusId: "4",
        stepId: 3,
        x: 1444.0,
        y: 355.0
    },  {
        description: "",
        id: "14CDB221-6ED0-7725-9893-1C32E0F0156C",
        initial: false,
        name: "Resolved",
        statusCategory: null,
        statusId: "5",
        stepId: 5,
        x: 1570.0,
        y: 218.0
    }],
    transitions: [{
        actionId: 21,
        description: null,
        globalTransition: false,
        name: "Close",
        sourceAngle: 45,
        sourceId: "14CDB221-6ED0-7725-9893-1C32E0F0156C",
        targetAngle: 135,
        targetId: "E90E7D73-93DB-9308-034D-1C32D0638647",
        screenName: null,
        screenId: null,
        transitionOptions: [{
            name: "properties",
            count: 3,
            url: "/properties/url",
            weight: 10
        }, {
            name: "conditions",
            count: 2,
            url: "/conditions/url",
            weight: 100
        }]
    }, {
        actionId: 1,
        description: null,
        globalTransition: false,
        name: "Create",
        sourceAngle: 0,
        sourceId: "BC195C3E-8BA3-6939-69B8-1C32527BD84D",
        targetAngle: 90,
        targetId: "A8055B98-2CF0-45FF-C616-1C3252A7DFC1",
        screenName: null,
        screenId: null,
        transitionOptions: [{
            name: "properties",
            count: 3,
            url: "/properties/url",
            weight: 10
        }, {
            name: "conditions",
            count: 2,
            url: "/conditions/url",
            weight: 100
        }]
    }, {
        actionId: 11,
        description: null,
        globalTransition: false,
        name: "Resolve",
        sourceAngle: 180,
        sourceId: "30C0CF0A-FFAF-2F19-F968-1C32841F7BA8",
        targetAngle: 315,
        targetId: "14CDB221-6ED0-7725-9893-1C32E0F0156C",
        screenName: null,
        screenId: null,
        transitionOptions: [{
            name: "properties",
            count: 3,
            url: "/properties/url",
            weight: 10
        }, {
            name: "conditions",
            count: 2,
            url: "/conditions/url",
            weight: 100
        }]
    }, {
        actionId: 31,
        description: null,
        globalTransition: false,
        name: "Start Progress",
        sourceAngle: 30,
        sourceId: "A8055B98-2CF0-45FF-C616-1C3252A7DFC1",
        targetAngle: 60,
        targetId: "30C0CF0A-FFAF-2F19-F968-1C32841F7BA8",
        screenName: null,
        screenId: null,
        transitionOptions: [{
            name: "properties",
            count: 3,
            url: "/properties/url",
            weight: 10
        }, {
            name: "conditions",
            count: 2,
            url: "/conditions/url",
            weight: 100
        }]
    }],
    updateAuthor: {
        userName: "bob",
        displayName: "Bob Dude"
    },
    updatedDate: 100000
};

simpleLayoutModelAttributes = {
    statuses: [{
        description: "",
        id: "E90E7D73-93DB-9308-034D-1C32D0638647",
        initial: false,
        name: "Closed",
        statusCategory: {
            colourName: "green",
            id: 1
        },
        statusId: "6",
        stepId: 4,
        x: 1318,
        y: 215,
        validations: null
    }, {
        description: "",
        id: "BC195C3E-8BA3-6939-69B8-1C32527BD84D",
        initial: true,
        name: "Create",
        statusCategory: null,
        statusId: null,
        stepId: 1,
        x: 1491,
        y: 22,
        validations: null
    }, {
        description: "",
        id: "30C0CF0A-FFAF-2F19-F968-1C32841F7BA8",
        initial: false,
        name: "In Progress",
        statusCategory: null,
        statusId: "3",
        stepId: 2,
        x: 1607,
        y: 99,
        validations: null
    }, {
        description: "",
        id: "A8055B98-2CF0-45FF-C616-1C3252A7DFC1",
        initial: false,
        name: "Open",
        statusCategory: null,
        statusId: "1",
        stepId: 1,
        x: 1290,
        y: 98,
        validations: null
    }, {
        description: "",
        id: "FCA5100A-F167-5B97-33A5-1C32B0CFE9B1",
        initial: false,
        name: "Reopened",
        statusCategory: null,
        statusId: "4",
        stepId: 3,
        x: 1444,
        y: 355,
        validations: null
    }, {
        description: "",
        id: "14CDB221-6ED0-7725-9893-1C32E0F0156C",
        initial: false,
        name: "Resolved",
        statusCategory: null,
        statusId: "5",
        stepId: 5,
        x: 1570,
        y: 218,
        validations: null
    }],
    transitions: [{
        id: "A<21:14CDB221-6ED0-7725-9893-1C32E0F0156C:E90E7D73-93DB-9308-034D-1C32D0638647>",
        actionId: 21,
        description: null,
        globalTransition: false,
        loopedTransition: false,
        name: "Close",
        sourceAngle: 45,
        sourceId: "14CDB221-6ED0-7725-9893-1C32E0F0156C",
        targetAngle: 135,
        targetId: "E90E7D73-93DB-9308-034D-1C32D0638647",
        screenName: null,
        screenId: null,
        transitionOptions: [{
            name: "properties",
            count: 3,
            url: "/properties/url",
            weight: 10
        }, {
            name: "conditions",
            count: 2,
            url: "/conditions/url",
            weight: 100
        }],
        validations: null
    }, {
        id: "IA<1:BC195C3E-8BA3-6939-69B8-1C32527BD84D:A8055B98-2CF0-45FF-C616-1C3252A7DFC1>",
        actionId: 1,
        description: null,
        globalTransition: false,
        loopedTransition: false,
        name: "Create",
        sourceAngle: 0,
        sourceId: "BC195C3E-8BA3-6939-69B8-1C32527BD84D",
        targetAngle: 90,
        targetId: "A8055B98-2CF0-45FF-C616-1C3252A7DFC1",
        screenName: null,
        screenId: null,
        transitionOptions: [{
            name: "properties",
            count: 3,
            url: "/properties/url",
            weight: 10
        }, {
            name: "conditions",
            count: 2,
            url: "/conditions/url",
            weight: 100
        }],
        validations: null
    }, {
        id: "A<11:30C0CF0A-FFAF-2F19-F968-1C32841F7BA8:14CDB221-6ED0-7725-9893-1C32E0F0156C>",
        actionId: 11,
        description: null,
        globalTransition: false,
        loopedTransition: false,
        name: "Resolve",
        sourceAngle: 180,
        sourceId: "30C0CF0A-FFAF-2F19-F968-1C32841F7BA8",
        targetAngle: 315,
        targetId: "14CDB221-6ED0-7725-9893-1C32E0F0156C",
        screenName: null,
        screenId: null,
        transitionOptions: [{
            name: "properties",
            count: 3,
            url: "/properties/url",
            weight: 10
        }, {
            name: "conditions",
            count: 2,
            url: "/conditions/url",
            weight: 100
        }],
        validations: null
    }, {
        id: "A<31:A8055B98-2CF0-45FF-C616-1C3252A7DFC1:30C0CF0A-FFAF-2F19-F968-1C32841F7BA8>",
        actionId: 31,
        description: null,
        globalTransition: false,
        loopedTransition: false,
        name: "Start Progress",
        sourceAngle: 30,
        sourceId: "A8055B98-2CF0-45FF-C616-1C3252A7DFC1",
        targetAngle: 60,
        targetId: "30C0CF0A-FFAF-2F19-F968-1C32841F7BA8",
        screenName: null,
        screenId: null,
        transitionOptions: [{
            name: "properties",
            count: 3,
            url: "/properties/url",
            weight: 10
        }, {
            name: "conditions",
            count: 2,
            url: "/conditions/url",
            weight: 100
        }],
        validations: null
    }],
    updateAuthor: {
        userName: "bob",
        displayName: "Bob Dude"
    },
    updatedDate: 100000
};
